summaryrefslogtreecommitdiffstats
path: root/base/sequence_checker_impl.h
diff options
context:
space:
mode:
authortommycli@chromium.org <tommycli@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-07-30 19:26:40 +0000
committertommycli@chromium.org <tommycli@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-07-30 19:26:40 +0000
commitd52426cf3429ee05807a97c7c22ed16494abb774 (patch)
treea7c9aa2c1b3974c8e985e577afbce7cc1803276a /base/sequence_checker_impl.h
parent71316604afb68ed5926ff25dc952c4d14000d2c1 (diff)
downloadchromium_src-d52426cf3429ee05807a97c7c22ed16494abb774.zip
chromium_src-d52426cf3429ee05807a97c7c22ed16494abb774.tar.gz
chromium_src-d52426cf3429ee05807a97c7c22ed16494abb774.tar.bz2
base: Re-re-apply WeakPtr support for SequencedWorkerPools
This is a continuation of https://codereview.chromium.org/20163004/#ps55001 and identical to Patchset 4. I'm adding back some death test threadsafe flags that got dropped from the re-apply. In other words, this CL is: https://codereview.chromium.org/20163004/#ps55001 + https://codereview.chromium.org/19617002/ Feel free to revert if it causes issues again. TBR=akalin,darin,dewittj,rnk BUG=165590 Review URL: https://codereview.chromium.org/20754006 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@214411 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'base/sequence_checker_impl.h')
-rw-r--r--base/sequence_checker_impl.h42
1 files changed, 18 insertions, 24 deletions
diff --git a/base/sequence_checker_impl.h b/base/sequence_checker_impl.h
index ccd1198..741aafe 100644
--- a/base/sequence_checker_impl.h
+++ b/base/sequence_checker_impl.h
@@ -7,48 +7,42 @@
#include "base/base_export.h"
#include "base/basictypes.h"
-#include "base/memory/ref_counted.h"
#include "base/synchronization/lock.h"
+#include "base/threading/sequenced_worker_pool.h"
#include "base/threading/thread_checker_impl.h"
namespace base {
-class SequencedTaskRunner;
-
// SequenceCheckerImpl is used to help verify that some methods of a
// class are called in sequence -- that is, called from the same
// SequencedTaskRunner. It is a generalization of ThreadChecker; in
// particular, it behaves exactly like ThreadChecker if its passed a
// NULL SequencedTaskRunner.
class BASE_EXPORT SequenceCheckerImpl {
public:
- // |sequenced_task_runner| can be NULL. In that case, this object
- // behaves exactly like a ThreadChecker bound to the current thread,
- // i.e. CalledOnValidSequence() behaves like CalledOnValidThread().
- explicit SequenceCheckerImpl(
- const scoped_refptr<SequencedTaskRunner>& sequenced_task_runner);
+ SequenceCheckerImpl();
~SequenceCheckerImpl();
- // Returns whether the we are being called on the underyling
- // SequencedTaskRunner. If we're not bound to a
- // |sequenced_task_runner|, returns whether we are being called on
- // the underlying ThreadChecker's thread.
- bool CalledOnValidSequence() const;
+ // Returns whether the we are being called on the same sequence token
+ // as previous calls. If there is no associated sequence, then returns
+ // whether we are being called on the underlying ThreadChecker's thread.
+ bool CalledOnValidSequencedThread() const;
- // Changes the underyling SequencedTaskRunner.
- // |sequenced_task_runner| can be NULL. In that case, this object
- // behaves exactly like a ThreadChecker that has been detached from
- // its thread, i.e. we will be bound to the thread on which we next
- // call CalledOnValidSequence().
- void ChangeSequence(
- const scoped_refptr<SequencedTaskRunner>& sequenced_task_runner);
+ // Unbinds the checker from the currently associated sequence. The
+ // checker will be re-bound on the next call to CalledOnValidSequence().
+ void DetachFromSequence();
private:
+ void EnsureSequenceTokenAssigned() const;
+
// Guards all variables below.
mutable Lock lock_;
- scoped_refptr<SequencedTaskRunner> sequenced_task_runner_;
- // Used if |sequenced_task_runner_| is NULL.
+
+ // Used if |sequence_token_| is not valid.
ThreadCheckerImpl thread_checker_;
+ mutable bool sequence_token_assigned_;
+
+ mutable SequencedWorkerPool::SequenceToken sequence_token_;
DISALLOW_COPY_AND_ASSIGN(SequenceCheckerImpl);
};
@@ -7,48 +7,42 @@
// class are called in sequence -- that is, called from the same
// SequencedTaskRunner. It is a generalization of ThreadChecker; in
-// particular, it behaves exactly like ThreadChecker if its passed a
-// NULL SequencedTaskRunner.
+// particular, it behaves exactly like ThreadChecker if constructed
+// on a thread that is not part of a SequencedWorkerPool.
class BASE_EXPORT SequenceCheckerImpl {
public: